activation
==========
.. currentmodule:: sinabs.activation

spiking activation
------------------

Spiking layers can choose any combination of spike generation, reset mechanism and surrogate gradient function.

.. toctree::
   :maxdepth: 1

   spike_generation
   reset_mechanism
   surrogate_gradient
